/******************************************************************************
*                                                                             *
*                             Module specification                            *
*                                                                             *
*                                 Copyright by                                *
*                                                                             *
*                               Azoteq (Pty) Ltd                              *
*                           Republic of South Africa                          *
*                                                                             *
*                            Tel: +27(0)21 863 0033                           *
*                                 www.azoteq.com                              *
*                                                                             *
*******************************************************************************
  Refer to IQS269 datasheet for more information, available here:
  - https://www.azoteq.com/design/datasheets/
*******************************************************************************
*                       IQS269A - Registers & Memory Map                      *
*******************************************************************************/

// Device Information
#define DEVICE_INFO         0x00    // Byte 0: PRODUCT_NUM    Byte 1: VERSION_NUM
									// Byte 0: HARDWARE_NUM   Byte 1: DEV_VERSION_NUM
// Flags
#define SYS_FLAGS           0x02    // Byte 0: SYSFLAGS       Byte 1: EVENTS
// Slider flags
#define GESTURE_FLAGS      	0x03    // Byte 0: GESTURE_FLAGS
// Channel Prox and Touch Flags
#define CH_PROX_STATE       0x04    // Byte 0: PROX_STATE     Byte 1: PROX_DIR
#define CH_TOUCH_STATE      0x05    // Byte 0: TOUCH_STATE    Byte 1: DEEP_STATE
// Channel Counts Bytes
#define ACF_CH0             0x08    // Byte 0: ACF_CH0_LOW    Byte 1: ACF_CH0_HIGH
#define ACF_CH1             0x0A    // Byte 0: ACF_CH1_LOW    Byte 1: ACF_CH1_HIGH
#define ACF_CH2             0x0C    // Byte 0: ACF_CH2_LOW    Byte 1: ACF_CH2_HIGH
#define ACF_CH3             0x0E    // Byte 0: ACF_CH3_LOW    Byte 1: ACF_CH3_HIGH
#define ACF_CH4             0x10    // Byte 0: ACF_CH4_LOW    Byte 1: ACF_CH4_HIGH
#define ACF_CH5             0x12    // Byte 0: ACF_CH5_LOW    Byte 1: ACF_CH5_HIGH
#define ACF_CH6             0x14    // Byte 0: ACF_CH6_LOW    Byte 1: ACF_CH6_HIGH
#define ACF_CH7             0x16    // Byte 0: ACF_CH7_LOW    Byte 1: ACF_CH7_HIGH
// Channel LTA Bytes
#define LTA_CH0             0x09    // Byte 0: LTA_CH0_LOW    Byte 1: LTA_CH0_HIGH
#define LTA_CH1             0x0B    // Byte 0: LTA_CH1_LOW    Byte 1: LTA_CH1_HIGH
#define LTA_CH2             0x0D    // Byte 0: LTA_CH2_LOW    Byte 1: LTA_CH2_HIGH
#define LTA_CH3             0x0F    // Byte 0: LTA_CH3_LOW    Byte 1: LTA_CH3_HIGH
#define LTA_CH4             0x11    // Byte 0: LTA_CH4_LOW    Byte 1: LTA_CH4_HIGH
#define LTA_CH5             0x13    // Byte 0: LTA_CH5_LOW    Byte 1: LTA_CH5_HIGH
#define LTA_CH6             0x15    // Byte 0: LTA_CH6_LOW    Byte 1: LTA_CH6_HIGH
#define LTA_CH7             0x17    // Byte 0: LTA_CH7_LOW    Byte 1: LTA_CH7_HIGH
// Channel Delta Bytes
#define DELTA_CH0           0x18    // Byte 0: DELTA_CH0_LOW  Byte 1: DELTA_CH0_HIGH
#define DELTA_CH1           0x19    // Byte 0: DELTA_CH1_LOW  Byte 1: DELTA_CH1_HIGH
#define DELTA_CH2           0x1A    // Byte 0: DELTA_CH2_LOW  Byte 1: DELTA_CH2_HIGH
#define DELTA_CH3           0x1B    // Byte 0: DELTA_CH3_LOW  Byte 1: DELTA_CH3_HIGH
#define DELTA_CH4           0x1C    // Byte 0: DELTA_CH4_LOW  Byte 1: DELTA_CH4_HIGH
#define DELTA_CH5           0x1D    // Byte 0: DELTA_CH5_LOW  Byte 1: DELTA_CH5_HIGH
#define DELTA_CH6           0x1E    // Byte 0: DELTA_CH6_LOW  Byte 1: DELTA_CH6_HIGH
#define DELTA_CH7           0x1F    // Byte 0: DELTA_CH6_LOW  Byte 1: DELTA_CH6_HIGH
// Reference Channel Delta Bytes
#define REFDELTA_CH0        0x20    // Byte 0: DELTA_CH0_LOW  Byte 1: DELTA_CH0_HIGH
#define REFDELTA_CH1        0x21    // Byte 0: DELTA_CH1_LOW  Byte 1: DELTA_CH1_HIGH
#define REFDELTA_CH2        0x22    // Byte 0: DELTA_CH2_LOW  Byte 1: DELTA_CH2_HIGH
#define REFDELTA_CH3        0x23    // Byte 0: DELTA_CH3_LOW  Byte 1: DELTA_CH3_HIGH
#define REFDELTA_CH4        0x24    // Byte 0: DELTA_CH4_LOW  Byte 1: DELTA_CH4_HIGH
#define REFDELTA_CH5        0x25    // Byte 0: DELTA_CH5_LOW  Byte 1: DELTA_CH5_HIGH
#define REFDELTA_CH6        0x26    // Byte 0: DELTA_CH6_LOW  Byte 1: DELTA_CH6_HIGH
#define REFDELTA_CH7        0x27    // Byte 0: DELTA_CH6_LOW  Byte 1: DELTA_CH6_HIGH
// Slider coordinates
#define COORDINATES			0x30	// Byte 0: SLIDER0_COR    Byte 1: SLIDER1_COR
//Capacitance Measurement Variables
#define CAP_ABS_BASE        0x31	// Byte 0: CAP_ABS_BASE_LOW   Byte 1: CAP_ABS_BASE_HIGH 
#define CAP_ABS_CS          0x32	// Byte 0: CAP_ABS_CS_LOW   Byte 1: CAP_ABS_CS_HIGH 
#define CAP_ABS_CS_CAP0     0x33	// Byte 0: CAP_ABS_CS_CAP0_LOW   Byte 1: CAP_ABS_CS_CAP0_HIGH 
#define CAP_ABS_CS_CAP1  	0x34	// Byte 0: CAP_ABS_CS_CAP1_LOW   Byte 1: CAP_ABS_CS_CAP1_HIGH
// Power mode settings Bytes
#define PMU_SETTINGS	   	0x80    // Byte 0: PMU_SETTINGS   Byte 1: I2C_SETTINGS
#define ACTIVE_CHANNELS     0x81    // Byte 0: ACTIVE_CHANNELS  Byte 1: FILTER_SETTINGS
#define CH_RESEED           0x82    // Byte 0: CH_RESEED      Byte 1: EVENT_MASK
// Report Rate Bytes
#define REPORT_RATES        0x83    // Byte 0: NM_PERIOD      Byte 1: LP_PERIOD
#define ULP_MODE_RATES      0x84    // Byte 0: ULP_PERIOD     Byte 1: MODE_PERIOD
#define TIMEOUT_PERIODS     0x85    // Byte 0: RDY_TIMEOUT    Byte 1: HALT_TIMEOUT
// General Settings
#define GEN_SETINGS  		0x86    // Byte 0: GEN_SETINGS0   Byte 1: GEN_SETINGS1
#define REF_SETTINGS        0x87    // Byte 0: ABS_CAP_SETTINGS Byte 1: REF_SETTINGS
#define EVENT_SETTINGS      0x88    // Byte 0: EVENT_SETTINGS Byte 1: MOV_SETTINGS
// Gesture Settings
#define SLIDER0_CH    		0x89    // Byte 0: SLIDER0_CH     Byte 1: SLIDER1_CH
#define TAP_SETTINGS        0x8A    // Byte 0: TAP_TIMER      Byte 1: SWIPE_TIMER
#define SWIPE_SETTINGS      0x8B    // Byte 0: SWIPE_THRESHOLD Byte 1: LTA_RESEED_CH
//Channel settings
#define CHx_REF_ASSOC		0x92	// Byte 0: REF_CH		Byte 1: REF_WEIGHT
#define CH6_PROX_SETTINGS	0xB7	// Byte 0: SETTINGS_0	Byte 1: SETTINGS_1
#define CH6_ATI_MIRROR		0xB9	// Byte 0: COARSE_FINE	Byte 1: PCC
#define CH7_ATI_MIRROR		0xC0	// Byte 0: COARSE_FINE	Byte 1: PCC

#define ATI_TARGETS         0x8E    // Byte 0: PROX_SETTING3 Byte 1: ATI_SETTINGS

//Engineering settings
#define ENG_DIRECT_ADDRESS  0xF0
#define ENG_DIRECT_DATA     0xF1
#define ENG_I2C_SETTINGS    0xF2
#define ENG_LAST_CONV_LSB   0xF3
#define ENG_LAST_CONV_MSB   0xF4
#define ENG_PXS_DETECTION   0xF5


